---
hide:
  - navigation
---

# Getting started

## Installation

=== "Pip"

```console
pip install aspen
```

=== "Development mode"

```console
git clone https://github.com/potassco/aspen.git/
cd aspen
pip install -e .[all]
```

!!! warning
    Use only for development purposes

## Usage

### Command line interface

Details about the command line usage can be found with:

```console
aspen -h
```
